# EphysVibe
Implementing pipeline analyses for electrophysiology data. 
Spiking and LFP activity of 32 channels linear probes from LIP; 64 Utah Arrays channels from PFC; 64 Utah Arrays channels from V4?
Animals perform a delay conjunction matching task, controlled by MonkeyLogic (Matlab): https://monkeylogic.nimh.nih.gov/
Raw electrophysiology data are acquired with OpenEphys: https://github.com/open-ephys



